==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1717.py <==
"""LengthVeryShort"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_LENGTH_VERY_SHORT = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "LengthVeryShort"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="LengthVeryShort")
    CastSelf = TypeVar("CastSelf", bound="LengthVeryShort._Cast_LengthVeryShort")


__docformat__ = "restructuredtext en"
__all__ = ("LengthVeryShort",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LengthVeryShort:
    """Special nested class for casting LengthVeryShort to subclasses."""

    __parent__: "LengthVeryShort"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def length_very_short(self: "CastSelf") -> "LengthVeryShort":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LengthVeryShort(_1652.MeasurementBase):
    """LengthVeryShort

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LENGTH_VERY_SHORT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LengthVeryShort":
        """Cast to another type.

        Returns:
            _Cast_LengthVeryShort
        """
        return _Cast_LengthVeryShort(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1717.py <==
"""Impulse"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_IMPULSE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Impulse"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Impulse")
    CastSelf = TypeVar("CastSelf", bound="Impulse._Cast_Impulse")


__docformat__ = "restructuredtext en"
__all__ = ("Impulse",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Impulse:
    """Special nested class for casting Impulse to subclasses."""

    __parent__: "Impulse"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def impulse(self: "CastSelf") -> "Impulse":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Impulse(_1666.MeasurementBase):
    """Impulse

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _IMPULSE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Impulse":
        """Cast to another type.

        Returns:
            _Cast_Impulse
        """
        return _Cast_Impulse(self)
